pub struct AssignClientId {
pub token: Option<String>,
}
Represents a request to reserve a client ID and return it. Client IDs are
unique only in the context of a room.
An arbitrary string value may be passed as a token. If the token has been
seen before in this room, the same value is returned every time.
The type of value that this handler will return.
Read more
This method is called for every message received by this actor.
The type of value that this message will resolved with if it is
successful.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Instruments this type with the provided
Span, returning an
Instrumented wrapper.
Read more
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.