Struct stateroom_server::AssignClientId
source · [−]pub struct AssignClientId;Expand description
Represents a request to reserve a client ID and return it. Client IDs are unique only in the context of a room.
Currently, client IDs are assigned sequentially, but this is an implementation detail and should not be relied on.