pub struct RoomActor { /* private fields */ }
Actor model representation of a “room”. A room is a set of clients that share an instance of a Stateroom instance. Conceptually, this is like a room in a chat service. Events (such as messages) and their side-effects are isolated to the room in which they occur.

Implementations

source

impl RoomActor

source

pub fn new(service_actor: Recipient<MessageFromClient>) -> Self